#!/usr/bin/env make -f

#-------------------------------------------------------------------------------
# General
#-------------------------------------------------------------------------------
SHELL          := /bin/sh

INSTALL         = /usr/bin/install
INSTALL_PROGRAM = $(INSTALL)
INSTALL_DATA    = $(INSTALL) -m 644
SED             = sed
RM             := rm -f
CP              = cp
MKDIR           = mkdir

INKSCAPE       := $(shell command -v inkscape 2> /dev/null)
YELP_BUILD     := $(shell command -v yelp-build 2> /dev/null)

#-------------------------------------------------------------------------------
# Usefull defines & functions
#-------------------------------------------------------------------------------
define \n


endef

#-------------------------------------------------------------------------------
# Path variables
#-------------------------------------------------------------------------------
TOP             = $(abspath $(dir $(firstword $(MAKEFILE_LIST))))

prefix          = /usr/local
exec_prefix     = $(prefix)
bindir          = $(exec_prefix)/bin
datarootdir     = $(prefix)/share
datadir         = $(datarootdir)
localedir       = $(datadir)/locale

builddir        = build
srcdir          = src
srcdatadir      = data

#-------------------------------------------------------------------------------
# Compile variables
#-------------------------------------------------------------------------------
CC             := cc
CFLAGS          = -Werror #-Wall -Wextra -Wstrict-prototypes -g
ALL_CFLAGS      = $(CFLAGS) `pkg-config --cflags gtk+-3.0 glib-2.0`
LDFLAGS         =
ALL_LDFLAGS     =
LDLIBS          =
ALL_LDLIBS      = $(LDLIBS) `pkg-config --libs gtk+-3.0 glib-2.0`

GLIB_COMPILE_RESOURCES  = glib-compile-resources
GLIB_COMPILE_SCHEMA     = glib-compile-schemas
GTK_UPDATE_ICON_CACHE   = gtk-update-icon-cache
UPDATE_DESKTOP_DATABASE = update-desktop-database

#-------------------------------------------------------------------------------
# Config variables
#-------------------------------------------------------------------------------
PACKAGE = boilerplate-for-c-and-gtk3
PACKAGE_ID = io.github.julianrichen.boilerplate
PACKAGE_NAME = Boilerplate for C and GTK3
PACKAGE_RESOURCES = /io/github/julianrichen/boilerplate

#PACKAGE = app
#PACKAGE_ID = org.example.app
#PACKAGE_NAME = app by example.org
#PACKAGE_RESOURCES = /org/example/app

PACKAGE_VERSION_MAJOR = 0
PACKAGE_VERSION_MINOR = 1
PACKAGE_VERSION_MICRO = 0
PACKAGE_VERSION = $(PACKAGE_VERSION_MAJOR).$(PACKAGE_VERSION_MINOR).$(PACKAGE_VERSION_MICRO)

PACKAGE_COPYRIGHT = Copyright \xc2\xa9 2017 Julian Richen

PACKAGE_SUMMARY = A boilerplate for quick GTK3 development in C

PACKAGE_URL_HOMEPAGE = https://github.com/julianrichen/boilerplate-for-c-gtk3
PACKAGE_URL_DOCS = https://github.com/julianrichen/boilerplate-for-c-gtk3/wiki
PACKAGE_URL_BUGS = https://github.com/julianrichen/boilerplate-for-c-gtk3/issues

GETTEXT_PACKAGE = $(PACKAGE)

#-------------------------------------------------------------------------------
# Custom gen_vars function
#
# Looks for @VARIABLE@ and replaces it with $(VARIABLE)
#
# Usage:
#     $(call gen_vars,[input],[output])
# Example:
#     $(call gen_vars,$<,$@)
#-------------------------------------------------------------------------------
define gen_vars
	@$(SED) \
	-e "s|\@PACKAGE\@|$(PACKAGE)|" \
	-e "s|\@PACKAGE_ID\@|$(PACKAGE_ID)|" \
	-e "s|\@PACKAGE_NAME\@|$(PACKAGE_NAME)|" \
	-e "s|\@PACKAGE_RESOURCES\@|$(PACKAGE_RESOURCES)|" \
	-e "s|\@PACKAGE_VERSION_MAJOR\@|$(PACKAGE_VERSION_MAJOR)|" \
	-e "s|\@PACKAGE_VERSION_MINOR\@|$(PACKAGE_VERSION_MINOR)|" \
	-e "s|\@PACKAGE_VERSION_MICRO\@|$(PACKAGE_VERSION_MICRO)|" \
	-e "s|\@PACKAGE_VERSION\@|$(PACKAGE_VERSION)|" \
	-e "s|\@PACKAGE_COPYRIGHT\@|$(PACKAGE_COPYRIGHT)|" \
	-e "s|\@PACKAGE_SUMMARY\@|$(PACKAGE_SUMMARY)|" \
	-e "s|\@PACKAGE_URL_HOMEPAGE\@|$(PACKAGE_URL_HOMEPAGE)|" \
	-e "s|\@PACKAGE_URL_DOCS\@|$(PACKAGE_URL_DOCS)|" \
	-e "s|\@PACKAGE_URL_BUGS\@|$(PACKAGE_URL_BUGS)|" \
	-e "s|\@GETTEXT_PACKAGE\@|$(GETTEXT_PACKAGE)|" \
	-e "s|\@localedir\@|$(localedir)|" \
	$(1) > $(2)
endef
